<?php
/**
 * Enrollment Theme Customizer panel for header.
 *
 * @package CodeVibrant
 * @subpackage Enrollment
 * @since 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

add_action( 'customize_register', 'enrollment_header_panel_register' );

if( ! function_exists( 'enrollment_header_panel_register' ) ):
function enrollment_header_panel_register( $wp_customize ) {

	/**
	 * Header Settings Panel on customizer
	 *
	 * @since 1.0.0
	 */
	$wp_customize->add_panel(
        'enrollment_header_settings_panel', 
        	array(
        		'priority'       => 10,
            	'capability'     => 'edit_theme_options',
            	'theme_supports' => '',
            	'title'          => __( 'Header Settings', 'enrollment' ),
            ) 
    );

/*------------------------------------------------------------------------------------------------------------------------------------*/
	/**
	 * Header Elements Section
	 *
	 * @since 1.0.0
	 */
	$wp_customize->add_section(
        'header_elements_section',
        array(
            'priority'       => 5,
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'panel'          => 'enrollment_header_settings_panel',
            'title'		     => __( 'Header Elements', 'enrollment' )
        )
    );

    /**
     * Select options for header elements types
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'enrollment_header_elements_type',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => 'default',
            'sanitize_callback' => 'enrollment_sanitize_select',
        )       
    );
    $wp_customize->add_control(
        'enrollment_header_elements_type',
        array(
            'label'         => __( 'Elements Type', 'enrollment' ),
            'description'   => __( 'Select the header elements content type.', 'enrollment' ),
            'section'       => 'header_elements_section',
            'settings'      => 'enrollment_header_elements_type',
            'type'          => 'select',
            'priority'      => 5,
            'choices' => array(
                'default'      => __( 'Default Elements', 'enrollment' ),
                'social_icons' => __( 'Social Icons Elements', 'enrollment' )
            )
        )
    );

    /**
     * Field for Address
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'header_address', 
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'transport'         => 'postMessage',
            'sanitize_callback' => 'sanitize_text_field'
       	)
    );
    $wp_customize->add_control(
        'header_address',
        array(
            'label'     => __( 'Header Address', 'enrollment' ),
            'section'   => 'header_elements_section',
            'settings'  => 'header_address',
            'type'      => 'text',
            'priority'  => 10,
            'active_callback' => 'enrollment_header_default_element_callback'
        )
    );

    /**
     * Field for email
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'header_email', 
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'transport'         => 'postMessage',
            'sanitize_callback' => 'enrollment_sanitize_email'
       	)
    );
    $wp_customize->add_control(
        'header_email',
        array(
            'label'     => __( 'Header E-mail', 'enrollment' ),
            'section'   => 'header_elements_section',
            'settings'  => 'header_email',
            'type'      => 'text',
            'priority'  => 15,
            'active_callback' => 'enrollment_header_default_element_callback'
        )
    );

    /**
     * Field for phone
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'header_phone', 
        array(
            'capability'        => 'edit_theme_options',
            'default'           => '',
            'transport'         => 'postMessage',
            'sanitize_callback' => 'sanitize_text_field'
       	)
    );
    $wp_customize->add_control(
        'header_phone',
        array(
            'label'     => __( 'Header Phone', 'enrollment' ),
            'section'   => 'header_elements_section',
            'settings'  => 'header_phone',
            'type'      => 'text',
            'priority'  => 20,
            'active_callback' => 'enrollment_header_default_element_callback'
        )
    );

    /**
     * Checkbox option for top social icons
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'enrollment_header_social_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'enrollment_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Enrollment_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'enrollment_header_social_option',
            array(
                'label'         => __( 'Header Social Icons', 'enrollment' ),
                'description'   => __( 'Option to control social icons at Header elements area section.', 'enrollment' ),
                'section'       => 'header_elements_section',
                'settings'      => 'enrollment_header_social_option',
                'priority'      => 25,
                'active_callback' => 'enrollment_header_social_element_callback'
            )
        )
    );

    
/*------------------------------------------------------------------------------------------------------------------------------------*/
	/**
	 * Additional Header settings
	 *
	 * @since 1.0.0
	 */
	$wp_customize->add_section(
        'additional_header_settings_section',
        array(
            'priority'       => 10,
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'panel'          => 'enrollment_header_settings_panel',
            'title'          => __( 'Additional Header Settings', 'enrollment' )
        )
    );

    /**
     * Checkbox option for sticky menu
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'enrollment_header_sticky_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'enrollment_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Enrollment_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'enrollment_header_sticky_option',
            array(
                'label'         => __( 'Sticky Menu', 'enrollment' ),
                'description'   => __( 'Option to control primary menu sticky.', 'enrollment' ),
                'section'       => 'additional_header_settings_section',
                'settings'      => 'enrollment_header_sticky_option',
                'priority'      => 5
            )
        )
    );

    /**
     * Checkbox option for search icon at primary menu
     *
     * @since 1.0.0
     */
    $wp_customize->add_setting(
        'enrollment_menu_search_option',
        array(
            'capability'        => 'edit_theme_options',
            'default'           => true,
            'sanitize_callback' => 'enrollment_sanitize_checkbox',
        )
    );
    $wp_customize->add_control( new Enrollment_Toggle_Checkbox_Custom_Control(
        $wp_customize, 
        'enrollment_menu_search_option',
            array(
                'label'         => __( 'Search Icon', 'enrollment' ),
                'description'   => __( 'Option to control search icon at primary menu section.', 'enrollment' ),
                'section'       => 'additional_header_settings_section',
                'settings'      => 'enrollment_menu_search_option',
                'priority'      => 10
            )
        )
    );

}// close function
endif;